@@ -393,6 +393,21 @@ const char *Subkey::publicKeyAlgorithmAsString() const
     return gpgme_pubkey_algo_name(subkey ? subkey->pubkey_algo : (gpgme_pubkey_algo_t)0);
 }
 
+std::string Subkey::algoName() const
+{
+#ifndef HAVE_GPGME_PUBKEY_ALGO_STRING
+    return std::string();
+#else
+    char *gpgmeStr;
+    if (subkey && (gpgmeStr = gpgme_pubkey_algo_string(subkey))) {
+        std::string ret = std::string(gpgmeStr);
+        gpgme_free(gpgmeStr);
+        return ret;
+    }
+    return std::string();
+#endif
+}
+
 bool Subkey::canEncrypt() const
 {
     return subkey && subkey->can_encrypt;
@@ -773,10 +788,7 @@ std::string UserID::Signature::statusAsString() const
     if (!sig) {
         return std::string();
     }
-    char buf[ 1024 ];
-    gpgme_strerror_r(sig->status, buf, sizeof buf);
-    buf[ sizeof buf - 1 ] = '\0';
-    return std::string(buf);
+    return gpgmepp_strerror_r(sig->status);
 }
 
 GpgME::Notation UserID::Signature::notation(unsigned int idx) const
